<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
// Do not use namespace to keep this on global space to keep the singleton initialization working
if (!class_exists('Openexchange_api_settings')) {

/**
 *
 * This is the main class for creating dashbord addon page and all submenu items
 *
 * Do not call or initialize this class directly, instead use the function mentioned at the bottom of this file
 */
    class Openexchange_api_settings
    {

        /**
         * None of these variables should be accessable from the outside of the class
         */
        private static $instance;

        /**
         * initialize the class and create dashboard page only one time
         */
        public static function init()
        {

            if (empty(self::$instance)) {
                return self::$instance = new self;
            }
            return self::$instance;

        }

        /**
         * Initialize the dashboard with specific plugins as per plugin tag
         *
         */
        public function cool_init_hooks()
        {
            add_action('admin_notices', array($this, 'Openexchange_api_key_notice'));
            add_action('admin_menu', array($this, 'Openexchange_add_submenu'), 100);
            add_action('cmb2_admin_init', array($this, 'Openexchange_settings_callback'));
            add_action('admin_head', array($this, 'Openexchange_custom_javascript_for_cmb2'));

        }

        function Openexchange_custom_javascript_for_cmb2()
        {
    // Enqueue jQuery if not already enqueued
    if (!wp_script_is('jquery', 'enqueued')) {
        wp_enqueue_script('jquery');
    }

    $script = <<<EOT
    <script>
        jQuery(document).ready(function($) {
            var url = window.location.href;
            var isSettingsPage = url.indexOf('?page=openexchange-api-settings') > 0;

            if (isSettingsPage) {
                $('[href="admin.php?page=openexchange-api-settings"]').parent('li').addClass('current');
            }

            var data = $('#adminmenu #toplevel_page_cool-crypto-plugins ul li a[href="admin.php?page=openexchange-api-settings"]');
            data.each(function() {
                if ($(this).is(':empty')) {
                    $(this).hide();
                }
            });
        });
    </script>
EOT;

    echo $script;
        }



        /**
         * This function will initialize the main dashboard menu for all plugins
         */
        public function Openexchange_add_submenu()
        {

            add_submenu_page('cool-crypto-plugins', 'API Settings', 'API Settings', 'manage_options', 'admin.php?page=openexchange-api-settings', false, 100);

        }

        /**
         * This function will render and create the HTML display of dashboard page.
         * All the HTML can be located in other template files.
         * Avoid using any HTML here or use nominal HTML tags inside this function.
         */
        public function Openexchange_settings_callback()
        {

            /**
             * Registers options page menu item and form.
             */
            $cool_options = new_cmb2_box(array(
                'id' => 'ccpw_settings_page',
                'title' => esc_html__('API Settings', 'celp1'),
                'object_types' => array('options-page'),

                /*
                 * The following parameters are specific to the options-page box
                 * Several of these parameters are passed along to add_menu_page()/add_submenu_page().
                 */

                'option_key' => 'openexchange-api-settings', // The option key and admin menu page slug.
                // 'icon_url'        => 'dashicons-palmtree', // Menu icon. Only applicable if 'parent_slug' is left empty.
                'menu_title' => false, // Falls back to 'title' (above).
                'parent_slug' => 'cool-crypto-plugins', // Make options page a submenu item of the themes menu.
                'capability' => 'manage_options', // Cap required to view options-page.
                'position' => 44, // Menu position. Only applicable if 'parent_slug' is left empty.
                // 'admin_menu_hook' => 'network_admin_menu', // 'network_admin_menu' to add network-level options page.
                // 'display_cb'      => false, // Override the options-page form output (CMB2_Hookup::options_page_output()).
                // 'save_button'     => esc_html__( 'Save Settings', 'celp1' ), // The text for the options-page save button. Defaults to 'Save'.
            ));

            /*
             * Options fields ids only need
             * to be unique within this box.
             * Prefix is not needed.
             */
            $cool_options->add_field(array(
                'name' => __('ENTER OPENEXCHANGERATES.ORG API KEY', 'ccpw1'),
                'id' => 'ccpw_openexchangerate_api_title',
                'type' => 'title',

            ));

            $cool_options->add_field(array(
                'name' => __('Enter API Key', 'ccpw1'),
                'desc' => __('Click Here To <a href="https://openexchangerates.org/signup/free" target="blank">Get Openexchangerates Free API Key</a>', 'ccpw1'),
                'id' => 'openexchangerate_api',
                'type' => 'text',

            ));

            $cool_options->add_field(array(
                'name' => __('Coingecko Api Settings', 'ccpw1'),
                'id' => 'ccpw_coingecko_api_title',
                'type' => 'title',

            ));

            $cool_options->add_field(array(
                'name' => __('Enter API Key', 'ccpw1'),
                'desc' => __('Check <a href="https://support.coingecko.com/hc/en-us/articles/21880397454233-User-Guide-How-to-use-Demo-plan-API-key-" target="blank">-How to retrieve Coingecko Free API Key ?</a>', 'ccpw1'),
                'id' => 'coingecko_api',
                'type' => 'text',

            ));
            $cool_options->add_field(
                array(
                    'name'    => 'Select API Cache Time',
                    'id'      => 'select_cache_time',
                    'desc'    => 'Trigger the API after that interval to load the most recent prices.',
                    'type'    => 'select',
                    'default' => '10',
                    'options' => array(
                        '5'  => __( '5 Minutes', 'cmb2' ),
                        '10' => __( '10 Minutes', 'cmb2' ),
                        '15' => __( '15 Minutes', 'cmb2' ),
                    ),
                    'desc'=>'Approximately 18,000 monthly API calls can be handled with a 5-minute API cache.<br>
                    Approximately 9,000 API calls per month can be managed with a 10-minute API cache.<br>
                    With a 15-minute API cache, you can support approximately 6,000 monthly API calls.',
                )
            );
            
            $total_hits=(get_option('cmc_coingecko_api_hits'))?get_option('cmc_coingecko_api_hits'):0;
            $cool_options->add_field(array(
                'name' => 'API Usage Report',
                'id' => 'ccpw_api_hit_title',
                'type' => 'title',    
                'desc' => '<div class="cmb-th"></div><div class="cmb-td"><table><tr><td>Total Monthly API Calls:-</td><td> <b>10000</b></td></tr><tr><td>Used API Calls:- </td><td><b>'.($total_hits?$total_hits:'').'</b></td><tr><tr><td>Remaining monthly API Calls:- </td><td><b>'.($total_hits?(10000-$total_hits):'').'</b></td><tr><td><a href="https://www.coingecko.com/en/developers/dashboard" target="blank">Click here to view API usage details</a></td><td></td></tr></table></div>',           

            ));
            
        }

        /*
        |----------------------------------------------------------------
        |   Admin notice for API Key registration admin users only
        |----------------------------------------------------------------
         */
        public function Openexchange_api_key_notice()
        {
         $api_option = get_option("openexchange-api-settings");     
        $api = (!empty($api_option['openexchangerate_api']))?$api_option['openexchangerate_api']:"";
        $coin_gecko_api = (!empty($api_option['coingecko_api']))?$api_option['coingecko_api']:"";
            if (!current_user_can('delete_posts')) {
                return;
            }
            $current_user = wp_get_current_user();
            $user_name = $current_user->display_name;
            $ajax_url = admin_url('admin-ajax.php');
            if(empty($api)){                
            ?>
			<div  class="license-warning notice notice-error is-dismissible">
				<p>Hi, <strong><?php echo ucwords($user_name); ?></strong>! Please <strong><a href="<?php echo esc_url(get_admin_url(null, 'admin.php?page=openexchange-api-settings')); ?>">enter</a></strong> Openexchangerates.org free API key for crypto to fiat price conversions.</p>
            <button type="button" class="notice-dismiss"><span class="screen-reader-text">Dismiss this notice.</span></button>
            </div>
		<?php
            }
            if(empty($coin_gecko_api)){
                ?>
                <div  class="license-warning notice notice-error is-dismissible">
                    <p>Hi, <strong><?php echo ucwords($user_name); ?></strong>! Please <strong><a href="<?php echo esc_url(get_admin_url(null, 'admin.php?page=openexchange-api-settings')); ?>">enter</a></strong> Coingecko free API key to work this plugin.</p>
                <button type="button" class="notice-dismiss"><span class="screen-reader-text">Dismiss this notice.</span></button>
                </div>
            <?php
                }
    }

   


    }

    /**
     *
     * initialize the main dashboard class with all required parameters
     */

    $Openexchange = Openexchange_api_settings::init();
    $Openexchange->cool_init_hooks();
  

}
