<?PHP

class CcpwRestApi
{
    public static $instanceApi;

    public static function getInstance()
    {
        if (!isset(self::$instanceApi)) {
            self::$instanceApi = new self();
        }
        return self::$instanceApi;
    }

    public function __construct()
    {
        add_action('rest_api_init', array($this, 'registerRestApi'));
    }

    public function registerRestApi()
    {
        register_rest_route('crypto-widget-pro', 'allDatass', array(
            'methods' => 'GET',
            'callback' => array($this, 'ccpwMainPaginationApiFunc'),
            'permission_callback' => '__return_true',
        ));

        register_rest_route('crypto-widget-pro', 'calculatorData', array(
            'methods' => 'GET',
            'callback' => array($this, 'ccpwCalcData'),
            'permission_callback' => '__return_true',
        ));

        register_rest_route('crypto-widget-pro', 'allData', array(
            'methods' => 'GET',
            'callback' => array($this, 'ccpwAllData'),
            'permission_callback' => '__return_true',
        ));
    }

    public function ccpwMainPaginationApiFunc($request)
    {
        $page = $request->get_param('page');
        $args = array(
            'number' => 20,
            'per_page' => $request['per_page'],
        );
        $per_page = $args['number'];
        $offset = ($page - 1) * $per_page;
        $coinslist = new ccpwp_database();
        $advanceTableData = $coinslist->get_coins(array(
            'number' => $per_page,
            'offset' => $offset,
        ));
        return $advanceTableData;
    }

    public function ccpwAllData($request)
    {
        $ccpwAllCoins = '';
        $urlcoinData = $request->get_params();

        $coinslist = new ccpwp_database();
        $coinslistap = new CCPWP_api_data();
        $bitcoin = ccpwp_coins_data("bitcoin");
        $btc_price = !empty($bitcoin[0]['price']) ? $bitcoin[0]['price'] : 1;
        $ccpwCurrency = $coinslistap->ccpwp_usd_conversions('all');
        $ccpwCurrency['BTC'] = (float) $btc_price;
        $allCoins = $coinslist->get_coins(array('number' => 250));

        if ($urlcoinData['coin'] != "false" && is_array($urlcoinData) && count($urlcoinData) != 0) {
            $getSavedIds = !empty(get_option("ccpw_coins_not_found")) ? get_option("ccpw_coins_not_found") : [];
            $newValues = $urlcoinData['coin'];
            update_option("ccpw_coins_not_found", array_merge($getSavedIds, $newValues));
            $results = $coinslist->get_coins(array('coin_id' =>array_merge($getSavedIds, $newValues)));
            $ccpwAllCoins = array_merge($allCoins, $results);
        } else {
            $customCoins = !empty(get_option("ccpw_coins_not_found")) ? get_option("ccpw_coins_not_found") : false;
            if ($customCoins) {
                $results = $coinslist->get_coins(array('coin_id' => $customCoins));
                $ccpwAllCoins = array_merge($allCoins, $results);
            } else {
                $ccpwAllCoins = $allCoins;
            }
        }

        $finalArray = [];
        foreach ($ccpwAllCoins as $coin) {
            $response = array();
            $response['coin_id'] = $coin->coin_id;
            $response['name'] = $coin->name;
            $response['symbol'] = $coin->symbol;
            $response['price'] = $coin->price;
            $response['percent_change_24h'] = $coin->percent_change_24h;
            $response['percent_change_1y'] = $coin->percent_change_1y;
            $response['percent_change_30d'] = $coin->percent_change_30d;
            $response['percent_change_7d'] = $coin->percent_change_7d;
            $response['market_cap'] = $coin->market_cap;
            $response['total_volume'] = $coin->total_volume;
            $response['circulating_supply'] = $coin->circulating_supply;
            $response['weekly_price_data'] = unserialize($coin->weekly_price_data);
            $response['logo'] = ccpwp_coin_logo_html($coin->coin_id, $size = 128, false);
            $finalArray[] = $response;
        }

        return array("fiat" => $ccpwCurrency, "crypto" => $finalArray);
    }

    public function ccpwCalcData($request)
    {
        $coinslist = new ccpwp_database();
        $coinslistap = new CCPWP_api_data();

        $calcDataArray = [];
        $coinIdArray = [];
        $finalArray = [];

        $ccpwAllCoins = $coinslist->get_column_specific_data(array('number' => -1, 'column' => 'symbol,coin_id,price,name'));
        $ccpwCurrency = $coinslistap->ccpwp_usd_conversions('all');

        foreach ($ccpwAllCoins as $value) {
            $coinIdArray[] = $value->coin_id;
            $calcDataArray1 = array("coin_id" => $value->coin_id, "symbol" => $value->symbol, "price" => $value->price, "name" => $value->name);
            array_push($calcDataArray, $calcDataArray1);
        }

        if (!class_exists('CoinMarketCap')) {
            $combinedData = [];
            for ($i = 500; $i <= 2500; $i = $i + 500) {
                $start = $i - 250;
                $combinedData[] = $coinslistap->ccpwp_get_coin_id_based_data(implode(",", array_slice($coinIdArray, $start, 500)), $i);
            }
            $comobine = [];
            foreach ($combinedData as $value) {
                foreach ($value as $keys => $valuess) {
                    $comobine[$keys] = $valuess;
                }
            }

            foreach ($calcDataArray as $value) {
                $finalArray[] = $calcDataArray1 = array(
                    "coin_id" => $value['coin_id'],
                    "symbol" => $value['symbol'],
                    "price" => (isset($comobine[$value['coin_id']])) ? $comobine[$value['coin_id']]['usd'] : $value['price'],
                    "name" => $value['name']
                );
            }
        } else {
            $finalArray = $calcDataArray;
        }

        return array("fiat" => $ccpwCurrency, "crypto" => $finalArray);
    }
}

CcpwRestApi::getInstance();
